@@ -1,18 +1,10 @@
 #! /usr/bin/env python
-# $Id: demo.py,v 2.7 2001/01/07 21:35:12 mhagger Exp $
+# $Id: demo.py,v 2.10 2003/04/21 09:44:09 mhagger Exp $
 
-# Copyright (C) 1999-2001 Michael Haggerty <mhagger@alum.mit.edu>
+# Copyright (C) 1999-2003 Michael Haggerty <mhagger@alum.mit.edu>
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.  This program is distributed in
-# the hope that it will be useful, but WITHOUT ANY WARRANTY; without
-# even the implied warranty of MERCHANTABILITY or FITNESS FOR A
-# PARTICULAR PURPOSE.  See the GNU General Public License for more
-# details; it is available at <http://www.fsf.org/copyleft/gpl.html>,
-# or by writing to the Free Software Foundation, Inc., 59 Temple Place
-# - Suite 330, Boston, MA 02111-1307, USA.
+# This file is licensed under the GNU Lesser General Public License
+# (LGPL).  See LICENSE.txt for details.
 
 """demo.py -- Demonstrate the Gnuplot python module.
 
@@ -21,27 +13,18 @@ the Gnuplot package, see test.py.
 
 """
 
-__cvs_version__ = '$Revision: 2.7 $'
+__cvs_version__ = '$Revision: 2.10 $'
 
 
-try:
-    # If the package has been installed correctly, this should work:
-    import Gnuplot, Gnuplot.funcutils
-except ImportError:
-    # It may be that the user is just testing out the package by
-    # running 'python demo.py' it the package's directory.  If that is
-    # the case, the following should work:
-    import __init__
-    Gnuplot = __init__
-    import funcutils
-    Gnuplot.funcutils = funcutils
+from Numeric import *
+
+# If the package has been installed correctly, this should work:
+import Gnuplot, Gnuplot.funcutils
 
 
 def demo():
     """Demonstrate the Gnuplot package."""
 
-    from Numeric import *
-
     # A straightforward use of gnuplot.  The `debug=1' switch is used
     # in these examples so that the commands that are sent to gnuplot
     # are also output on stderr.
