@@ -1,17 +1,9 @@
-# $Id: gp.py,v 2.9 2001/01/07 21:35:13 mhagger Exp $
+# $Id: gp.py,v 2.13 2003/04/21 09:44:09 mhagger Exp $
 
-# Copyright (C) 1998,1999 Michael Haggerty <mhagger@alum.mit.edu>
+# Copyright (C) 1998-2003 Michael Haggerty <mhagger@alum.mit.edu>
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.  This program is distributed in
-# the hope that it will be useful, but WITHOUT ANY WARRANTY; without
-# even the implied warranty of MERCHANTABILITY or FITNESS FOR A
-# PARTICULAR PURPOSE.  See the GNU General Public License for more
-# details; it is available at <http://www.fsf.org/copyleft/gpl.html>,
-# or by writing to the Free Software Foundation, Inc., 59 Temple Place
-# - Suite 330, Boston, MA 02111-1307, USA.
+# This file is licensed under the GNU Lesser General Public License
+# (LGPL).  See LICENSE.txt for details.
 
 """gp -- a platform-independent interface to a gnuplot process.
 
@@ -28,7 +20,7 @@ gp_*.py modules.
 
 """
 
-__cvs_version__ = '$Revision: 2.9 $'
+__cvs_version__ = '$Revision: 2.13 $'
 
 import sys
 
@@ -39,6 +31,12 @@ if sys.platform == 'mac':
     from gp_mac import GnuplotOpts, GnuplotProcess, test_persist
 elif sys.platform == 'win32':
     from gp_win32 import GnuplotOpts, GnuplotProcess, test_persist
+elif sys.platform == 'darwin':
+    from gp_macosx import GnuplotOpts, GnuplotProcess, test_persist
+elif sys.platform[:4] == 'java':
+    from gp_java import GnuplotOpts, GnuplotProcess, test_persist
+elif sys.platform == 'cygwin':
+    from gp_cygwin import GnuplotOpts, GnuplotProcess, test_persist
 else:
     from gp_unix import GnuplotOpts, GnuplotProcess, test_persist
 
